package com.alihealth.d2d.provtest.service.handle.business;

import com.alihealth.d2d.provtest.domain.DrugInvoiceApplyInfo;
import com.alihealth.d2d.provtest.entity.EventBasic;
import com.alihealth.d2d.provtest.entity.EventBody;
import com.alihealth.d2d.provtest.entity.InstanceDetail;
import com.alihealth.d2d.provtest.entity.ItemDetail;
import com.alihealth.d2d.provtest.service.IDrugInvoiceApplyInfoService;
import com.alihealth.d2d.provtest.service.handle.AbstractEventDataHandler;
import com.alihealth.d2d.provtest.service.handle.EventSubType;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;

/**
 * @author Jason
 * @date 2025年06月05日 11:37:52
 */
@EventSubType("2015")
@Service
public class SubType2015Handler extends AbstractEventDataHandler<DrugInvoiceApplyInfo> {

    @Autowired
    private IDrugInvoiceApplyInfoService service;

    @Override
    protected Class<DrugInvoiceApplyInfo> getEntityClass() {
        return DrugInvoiceApplyInfo.class;
    }

    @Override
    protected IService<DrugInvoiceApplyInfo> getService() {
        return service;
    }

    @Override
    protected DrugInvoiceApplyInfo convertToEntity(EventBody eventBody, ItemDetail item, InstanceDetail instance) {
        EventBasic evtBasic = eventBody.getEvtBasic();
        SimpleDateFormat formatterDatetime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        //日期格式
        SimpleDateFormat formatterDate = new SimpleDateFormat("yyyyMMdd");
        try {
            return
                    DrugInvoiceApplyInfo.builder()
                            .eventId(eventBody.getEventID())
                            .recTime(formatterDatetime.parse(eventBody.getRecTime()))

                            .ypzsm(instance.getString("YPZSM"))
                            .syjbzypzsm(instance.getString("SYJBZYPZSM"))
                            .bzcj(instance.getString("BZCJ"))
                            .ymzt(instance.getString("YMZT"))

                            .tyshxydmscqy(item.getString("TYSHXYDMSCQY"))
                            .scqymc(item.getString("SCQYMC"))
                            .yptymc(item.getString("YPTYMC"))
                            .gjypbsm(item.getString("GJYPBSM"))
                            .ymscph(item.getString("YMSCPH"))
                            .tyshxydmjkymdlqy(item.getString("TYSHXYDMJKYMDLQY"))
                            .jkymdlqymc(item.getString("JKYMDLQYMC"))
                            .scrq(formatterDate.parse(item.getString("SCRQ")))
                            .ymyxqjzrq(formatterDate.parse(item.getString("YMYXQJZRQ")))

                            .fhsl(item.getInt("FHSL"))
                            .yppzwh(item.getString("YPPZWH"))
                            .yppzwhyxq(formatterDate.parse(item.getString("YPPZWHYXQ")))
                            .jx(item.getString("JX"))
                            .bzgg(item.getString("BZGG"))
                            .zjgg(item.getString("ZJGG"))
                            .bzzhb(Integer.parseInt(item.getString("BZZHB")))
                            .bzzhbdw(item.getString("BZZHBDW"))
                            .ypzcfl(item.getString("YPZCFL"))
                            .tsypglfl(item.getString("TSYPGLFL"))
                            .yjbgqszt(item.getString("YJBGQSZT"))
                            .yjbggzzt(item.getString("YJBGGZZT"))

                            .fhdbh(evtBasic.getString("FHDBH"))
                            .dhdbh(evtBasic.getString("DHDBH"))
                            .tyshxydmfhjg(evtBasic.getString("TYSHXYDMFHJG"))
                            .jzdwbmfhjg(evtBasic.getString("JZDWBMFHJG"))
                            .fhjgmc(evtBasic.getString("FHJGMC"))
                            .fhdz(evtBasic.getString("FHDZ"))
                            .fhlx(evtBasic.getString("FHLX"))
                            .fhsj(formatterDatetime.parse(evtBasic.getString("FHSJ")))
                            .tyshxydmshjg(evtBasic.getString("TYSHXYDMSHJG"))
                            .jzdwbmshjg(evtBasic.getString("JZDWBMSHJG"))
                            .shdz(evtBasic.getString("SHDZ"))
                            .shjgmc(evtBasic.getString("SHJGMC"))
                            .tyshxydmympsdw(evtBasic.getString("TYSHXYDMYMPSDW"))
                            .ympsdwmc(evtBasic.getString("YMPSDWMC"))
                            .djyzzt(evtBasic.getString("DJYZZT"))
                            .djyzrq(formatterDate.parse(evtBasic.getString("DJYZRQ")))
                            .djyzwtgyy(evtBasic.getString("DJYZWTGYY"))
                            .fhdczr(evtBasic.getString("FHDCZR"))
                            .fhdscsj(formatterDate.parse(evtBasic.getString("FHDSCSJ")))
                            .fhr(evtBasic.getString("FHR"))
                            .fhjglx(evtBasic.getString("FHJGLX"))
                            .shjglx(evtBasic.getString("SHJGLX"))
                            .fhjgxl(evtBasic.getString("FHJGXL"))
                            .shjgxl(evtBasic.getString("SHJGXL"))
                            .wsjgdmshjg(evtBasic.getString("WSJGDMSHJG"))
                            .wsjgdmfhjg(evtBasic.getString("WSJGDMFHJG"))
                            .zyxkzdjhfhjg(evtBasic.getString("ZYXKZDJHFHJG"))
                            .zyxkzdjhshjg(evtBasic.getString("ZYXKZDJHSHJG"))
//                            .wtdwmc(evtBasic.getString("WTDWMC"))
//                            .wtdwtyshxydm(evtBasic.getString("WTDWTYSHXYDM"))
                            .jsbs(evtBasic.getString("JSBS"))
//                            .jsyy(evtBasic.getString("JSYY"))
//                            .jssj(evtBasic.getDate("JSSJ"))
                            .build();


        } catch (ParseException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public String getSubType() {
        return "2015";
    }

    @Override
    public void handleBase(String xml, String eventId) {

    }
}
